/**
 * 短信主要逻辑
 */

const QcloudSms = require("qcloudsms_js");
import { SMSTYPE } from "../config/enum";
import { systemConfig } from "../config/serverConfig";

/**实例化 QcloudSms */
var qcloudsms;
export function initSMS() {
    qcloudsms = QcloudSms(systemConfig.smsSDKId, systemConfig.smsAppKey);
}

/**
 * 给特定账号发送信息
 * @param phone 需要发送的电话数组
 * @param type 类别
 * @param params 参数数组
 */
function sendMsmToPhoneNumber(phone, type:number, params) {
    var ssender = qcloudsms.SmsSingleSender();

    let templateId = -1;
    if (type == SMSTYPE.修改密码) templateId = systemConfig.smsModelChangePwd;
    else if (type == SMSTYPE.信息填报提醒) templateId = systemConfig.smsModelPointOut;
    else if (type == SMSTYPE.创建孵化器提醒) templateId = systemConfig.smsModelInitPointOut;

    return new Promise( (resolve, reject) => {
        ssender.sendWithParam("86", phone, templateId, params, systemConfig.smsSign, "", "", function (err, res, resData) {
            let isError = false;
            let msg = "";
            if (err) {
                msg = err;
                isError = true;
            } else {
                console.log("request data: ", res.req);
                console.log("response data: ", resData);
                //todo
                if (resData.errmsg != 'OK') {
                    isError = true;
                    msg = resData.errmsg;
                }
            }
            resolve({isError, msg});
        });
    })
}


/**
 * 发送修改密码的短信验证码
 * @param phone 
 * @param code 
 */
export async function sendChangePwdCode(phone:string, code:string) {
    let sendPhoneList = [phone];
    let params = [code];
    let sendRes:any = await sendMsmToPhoneNumber(sendPhoneList, SMSTYPE.修改密码, params);

    return sendRes.isError;
}


/**
 * 发送任务提醒
 * @param phoneList  发送的对象列表 
 * @param month 月份数
 * @returns 
 */
export async function sendTaskPointOut(phoneList, month:number) {
    let sendRes:any = await sendMsmToPhoneNumber(phoneList, SMSTYPE.修改密码, [month]);
    return sendRes.isError;
}


/**
 * 创建孵化器发送初始密码消息
 * @param phone 发送的对象号码
 * @returns 
 */
export async function sendInitPointOut(phone:string) {
    let sendPhoneList = [phone];
    let sendRes:any = await sendMsmToPhoneNumber(sendPhoneList, SMSTYPE.修改密码, []);

    return sendRes.isError;
}
